@@ -37,11 +37,9 @@ THE SOFTWARE. */
 
 #include "OptionsDialog.hpp"
 #include "AboutDialog.hpp"
+#include "Preferences.hpp"
 
 
-inline ting::uint DHighestOctave(){
-	return 7;
-};
 
 class MainWindow : public Hildon::Window{
 	ting::Ref<aumiks::Instrument> instr;//current instrument
@@ -51,6 +49,8 @@ class MainWindow : public Hildon::Window{
 
 	Gtk::Menu mainMenu;
 	Gtk::MenuItem optionsMenuItem;
+	Gtk::MenuItem saveTuningMenuItem;
+	Gtk::SeparatorMenuItem menuSeparator2;
 	Gtk::MenuItem exitMenuItem;
 	Gtk::SeparatorMenuItem menuSeparator1;
 	Gtk::MenuItem aboutMenuItem;
@@ -58,11 +58,9 @@ class MainWindow : public Hildon::Window{
 	OptionsDialog optionsDialog;
 	AboutDialog aboutDialog;
 
-	ting::uint numOctaves;
+	Preferences prefs;
 
-	ting::uint curOctave;
-
-	ting::uint basePitch;//step number starting from A0 (27.5Hz)
+	ting::uint curOctave;//for locking to first tapped octave
 
 	float tappedX;
 public:
@@ -79,11 +77,11 @@ public:
 	void ShowOptionsDialog();
 	void ShowAboutDialog();
 
-	void ApplyTimbre(OptionsDialog::E_Timbre timbre);
-	OptionsDialog::E_Timbre GetCurrentTimbreType()const;
+	void ApplyTimbre(Preferences::E_Timbre timbre);
+	Preferences::E_Timbre GetCurrentTimbreType()const;
 
 	inline ting::uint PitchRange()const{
-		return this->numOctaves * 12;
+		return this->prefs.GetNumOctaves() * 12;
 	};
 
 	struct FreqVol{
@@ -95,15 +93,13 @@ public:
 	//otherwise the old value will be used
 	FreqVol CalcFreqAndVol(float scrW, float scrH, float tapX, float tapY, bool isPressEvent);
 
-	static inline char* DPreferencesFileName(){
+	static inline const char* DPreferencesFileName(){
 		return "preferences.xml";
 	}
 
 	void LoadPreferencesFromFile();
 	void SavePreferencesToFile();
 
-	void ClampBasePitch();
-
 	void Exit();
 
 	static float CalcFreq(float baseFreq, float numOctavesToShift);
